@@ -325,7 +325,8 @@ cupsImageOpen(
 
   fseek(fp, 2048, SEEK_SET);
   memset(header2, 0, sizeof(header2));
-  fread(header2, 1, sizeof(header2), fp);
+  if (fread(header2, 1, sizeof(header2), fp) == 0 && ferror(fp))
+    DEBUG_printf(("Error reading file!"));
   fseek(fp, 0, SEEK_SET);
 
  /*
@@ -661,7 +662,9 @@ flush_tile(cups_image_t *img)		/* I - Image */
     }
   }
 
-  write(img->cachefile, tile->ic->pixels, bpp * CUPS_TILE_SIZE * CUPS_TILE_SIZE);
+  if (write(img->cachefile, tile->ic->pixels,
+	    bpp * CUPS_TILE_SIZE * CUPS_TILE_SIZE) == -1)
+    DEBUG_printf(("Error writing cache tile!"));
 
   tile->ic    = NULL;
   tile->dirty = 0;
@@ -753,7 +756,9 @@ get_tile(cups_image_t *img,		/* I - Image */
                     CUPS_LLCAST tile->pos));
 
       lseek(img->cachefile, tile->pos, SEEK_SET);
-      read(img->cachefile, ic->pixels, bpp * CUPS_TILE_SIZE * CUPS_TILE_SIZE);
+      if (read(img->cachefile, ic->pixels,
+	       bpp * CUPS_TILE_SIZE * CUPS_TILE_SIZE) == -1)
+	DEBUG_printf(("Error reading cache tile!"));
     }
     else
     {
@@ -802,3 +807,30 @@ get_tile(cups_image_t *img,		/* I - Image */
   return (ic->pixels + bpp * (y * CUPS_TILE_SIZE + x));
 }
 
+/*
+ * Crop a image.
+ * (posw,posh): Position of left corner
+ * (width,height): width and height of required image.
+ */
+cups_image_t* cupsImageCrop(cups_image_t* img,int posw,int posh,int width,int height)
+{
+  int image_width = cupsImageGetWidth(img);
+  cups_image_t* temp=calloc(sizeof(cups_image_t),1);
+  cups_ib_t *pixels=(cups_ib_t*)malloc(img->xsize*cupsImageGetDepth(img));
+  temp->cachefile = -1;
+  temp->max_ics = CUPS_TILE_MINIMUM;
+  temp->colorspace=img->colorspace;
+  temp->xppi = img->xppi;
+  temp->yppi = img->yppi;
+  temp->num_ics = 0;
+  temp->first =temp->last = NULL;
+  temp->tiles = NULL;
+  temp->xsize = width;
+  temp->ysize = height;
+  for(int i=posh;i<min(cupsImageGetHeight(img),posh+height);i++){
+    cupsImageGetRow(img,posw,i,min(width,image_width-posw),pixels);
+    _cupsImagePutRow(temp,0,i-posh,min(width,image_width-posw),pixels);
+  }
+  free(pixels);
+  return temp;
+}
